Module reference
================

The framework's API documentation can be found here.

.. toctree::
   :maxdepth: 2

   kite.scene
   kite.quadtree
   kite.covariance
   kite.spool
   kite.sandboxscene
   kite.sources
